window.onload = function () {
    let spread = new GC.Spread.Sheets.Workbook(document.getElementById("ss"), {sheetCount: 4});
    initSpread(spread);
};

function initSpread(spread) {
    spread.suspendPaint();
    spread.setSheetCount(2);
    let sheet1 = spread.getSheet(0);
    let sheet2 = spread.getSheet(1);
    let tableName = getDataSource(sheet2, pivotSales);
    initPivotTable(sheet1, tableName);
    spread.resumePaint();
}

function getDataSource(sheet, tableSource) {
    sheet.name("DataSource");
    sheet.setRowCount(55);
    sheet.setColumnWidth(0, 120);
    sheet.setDataSource(tableSource);
    sheet.addRows(0, 1);
    let table = sheet.tables.add('table', 0, 0, 201, 10);
    table.style(GC.Spread.Sheets.Tables.TableThemes["none"]);
    sheet.getCell(0,0).text("Name");
    sheet.getCell(0,1).text("Platform");
    sheet.getCell(0,2).text("Year");
    sheet.getCell(0,3).text("Genre");
    sheet.getCell(0,4).text("Publisher");
    sheet.getCell(0,5).text("NA_Sales");
    sheet.getCell(0,6).text("EU_Sales");
    sheet.getCell(0,7).text("JP_Sales");        
    sheet.getCell(0,8).text("Other_Sales");        
    sheet.getCell(0,9).text("Global_Sales");
    return table.name();
}

function initPivotTable(sheet, tableName) {
    sheet.name("Basic PivotTable");
    sheet.setRowCount(250);
    let pivotTableOptions = {bandRows:true,bandColumns:true};
    // Create Pivot Table
    let pivotTable = sheet.pivotTables.add("PivotTable", tableName, 1, 1, GC.Spread.Pivot.PivotTableLayoutType.tabular, GC.Spread.Pivot.PivotTableThemes.medium14, pivotTableOptions);
    pivotTable.suspendLayout();

    pivotTable.add("Genre", "Genre", GC.Spread.Pivot.PivotTableFieldType.rowField);
    pivotTable.add("Name", "Name", GC.Spread.Pivot.PivotTableFieldType.rowField);
    pivotTable.add("NA_Sales", "NA_Sales", GC.Spread.Pivot.PivotTableFieldType.valueField, GC.Pivot.SubtotalType.sum);
    pivotTable.add("EU_Sales", "EU_Sales", GC.Spread.Pivot.PivotTableFieldType.valueField, GC.Pivot.SubtotalType.sum);
    pivotTable.add("JP_Sales", "JP_Sales", GC.Spread.Pivot.PivotTableFieldType.valueField, GC.Pivot.SubtotalType.sum);
    pivotTable.add("Other_Sales", "Other_Sales", GC.Spread.Pivot.PivotTableFieldType.valueField, GC.Pivot.SubtotalType.sum);
    pivotTable.add("Global_Sales", "Global_Sales", GC.Spread.Pivot.PivotTableFieldType.valueField, GC.Pivot.SubtotalType.sum);

    // Add Pivot Style 
    let panel = new GC.Spread.Pivot.PivotPanel("myPivotPanel", pivotTable, document.getElementById("panel"));
    panel.sectionVisibility(GC.Spread.Pivot.PivotPanelSection.fields + GC.Spread.Pivot.PivotPanelSection.area);
    
    let labelPivotArea = {
        dataOnly: true,
        references: [{
            fieldName: "Values",
            items: ["Global_Sales", ,"JP_Sales", "NA_Sales"]
        }]
    };
    let style = new GC.Spread.Sheets.Style();
    style.backColor = "#82bc00";
    pivotTable.setStyle(labelPivotArea, style);

    pivotTable.resumeLayout();
    // Auto fit columns
    pivotTable.autoFitColumn();
}